# NeonAI LibreTranslate Language Plugin
Language Plugin for LibreTranslate language detection and translation

# Configuration:

```yaml
keys:
  libretranslate: {"libretranslate_host": "https://libretranslate.2022.us",
           "key": "<LIBRETRANSLATE_API_KEY>"}
```